﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ViewSourceFilterExample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window, INotifyPropertyChanged
    {
        private ObservableCollection<Person> _listPersons = new ObservableCollection<Person>();

        public event PropertyChangedEventHandler PropertyChanged;

        internal CollectionViewSource PersonViewSource
        {
            get; set;
        } = new CollectionViewSource();

        public ICollectionView PersonView
        {
            get { return PersonViewSource.View; }
        }

        protected void NotifyPropertyChanged([CallerMemberName] string name = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(name));
        }

        private string _filterText = "";

        public string FilterText
        {
            get
            {
                return _filterText;
            }

            set
            {
                _filterText = value;
                NotifyPropertyChanged();
                PersonView.Refresh();
            }
        }

        public MainWindow()
        {           
            _listPersons.Add(new Person() { Name = "Ebe", FavoriteBeer = "Augustiner" });            
            _listPersons.Add(new Person() { Name = "Andy", FavoriteBeer = "Öttinger" });
            _listPersons.Add(new Person() { Name = "Herbie", FavoriteBeer = "Reischenau Gold" });
            _listPersons.Add(new Person() { Name = "Erwin", FavoriteBeer = "Heineken" });
            _listPersons.Add(new Person() { Name = "Wolfram", FavoriteBeer = "Dein Bier" });
            _listPersons.Add(new Person() { Name = "Klaus", FavoriteBeer = "Radeberger" });
            _listPersons.Add(new Person() { Name = "Kiwi", FavoriteBeer = "Meisterpils" });
            _listPersons.Add(new Person() { Name = "Peter", FavoriteBeer = "Dein Bier" });

            PersonViewSource.Source = _listPersons;
            PersonViewSource.Filter += PersonViewSource_Filter;

            InitializeComponent();
            this.DataContext = this;
        }

        private void PersonViewSource_Filter(object sender, FilterEventArgs e)
        {
            if (string.IsNullOrWhiteSpace(_filterText))
            {
                //no filter when no search text is entered
                e.Accepted = true;
            } else
            {
                Person p = (Person)e.Item;
                if (p.Name.StartsWith(_filterText) || p.FavoriteBeer.StartsWith(_filterText))
                {
                    e.Accepted = true;
                } else
                {
                    e.Accepted = false;
                }
            }
        }
    }
}
